# src/ecommerce_toolkit/config.py
import os
from typing import Optional
import requests
from urllib.parse import urlparse
from dotenv import load_dotenv

class StoreConfig:
    def __init__(self):
        load_dotenv()
        self.store_url = os.getenv("STORE_URL")
        self.store_type = self._detect_store_type()
        
        # Shopify specific
        self.shopify_token = os.getenv("SHOPIFY_ACCESS_TOKEN")
        
        # WooCommerce specific
        self.woo_key = os.getenv("WOO_CONSUMER_KEY")
        self.woo_secret = os.getenv("WOO_CONSUMER_SECRET")
        
        if not self.store_url:
            raise ValueError("STORE_URL environment variable is required")
    
    def _detect_store_type(self) -> str:
        """Detect store type from URL or environment variable"""
        if not self.store_url:
            return None
            
        store_type = os.getenv("STORE_TYPE")
        if store_type:
            return store_type.lower()
            
        domain = urlparse(self.store_url).netloc
        if "myshopify.com" in domain:
            return "shopify"
        elif any(wp_indicator in requests.get(f"https://{domain}").text.lower() 
                for wp_indicator in ["wp-content", "wp-includes"]):
            return "woocommerce"
        
        raise ValueError("Could not detect store type. Please set STORE_TYPE environment variable.")
