# src/ecommerce_toolkit/providers/woocommerce.py
import requests
from typing import List
from .base import EcommerceProvider
from ..models.product import Product

class WooCommerceProvider(EcommerceProvider):
    def __init__(self, shop_url: str, consumer_key: str, consumer_secret: str):
        self.base_url = f"https://{shop_url}/wp-json/wc/v3"
        self.auth = (consumer_key, consumer_secret)
    
    def get_products(self) -> List[Product]:
        response = requests.get(
            f"{self.base_url}/products",
            auth=self.auth
        )
        response.raise_for_status()
        products = response.json()
        return [
            Product(
                id=str(p["id"]),
                name=p["name"],
                price=float(p["price"]),
                stock=int(p["stock_quantity"] or 0),
                description=p.get("description")
            )
            for p in products
        ]
    
    def get_product(self, product_id: str) -> Product:
        response = requests.get(
            f"{self.base_url}/products/{product_id}",
            auth=self.auth
        )
        response.raise_for_status()
        p = response.json()
        return Product(
            id=str(p["id"]),
            name=p["name"],
            price=float(p["price"]),
            stock=int(p["stock_quantity"] or 0),
            description=p.get("description")
        )
    
    def search_products(self, query: str) -> List[Product]:
        response = requests.get(
            f"{self.base_url}/products",
            params={"search": query},
            auth=self.auth
        )
        response.raise_for_status()
        products = response.json()
        return [
            Product(
                id=str(p["id"]),
                name=p["name"],
                price=float(p["price"]),
                stock=int(p["stock_quantity"] or 0),
                description=p.get("description")
            )
            for p in products
        ]
